@@ -1,11 +1,12 @@
 package App::Unix::RPasswd::Connection;
+# This is an internal module of App::Unix::RPasswd
 
 use namespace::autoclean;
 use feature ':5.10';
 use Moose;
 use Expect;
 
-our $VERSION = '0.3';
+our $VERSION = '0.31';
 our $AUTHOR  = 'Claudio Ramirez <nxadm@cpan.org>';
 
 has 'user' => (
@@ -62,41 +63,4 @@ sub _construct_cmd {
 
 no Moose;
 __PACKAGE__->meta->make_immutable;
-1;
-__END__
-
-=pod
-
-=head1 NAME
-
-App::Unix::RPasswd::Connection - Run passwd remotely
-
-=head1 VERSION
-
-Version 0.3
-
-=head1 SYNOPSIS
-
-B<This is an internal module of App::Unix::RPasswd.> 
-
-=head1 AUTHOR
-
-Claudio Ramirez <nxadm@cpan.org>
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2010 Claudio Ramirez.
-This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-=cut
\ No newline at end of file
+1;
\ No newline at end of file
